/*
    *
    * This file is a part of Libcsys.
    * Library for managing drive and getting system resource information in real time for CuboCore Application Suite
	* Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/


#include "command_util.h"

#include <QProcess>
#include <QTextStream>
#include <QStandardPaths>


QString CommandUtil::sudoExec( const QString &cmd, QStringList args, QByteArray data )
{
    args.push_front( cmd );

    QString result( "" );

    try {
        result = CommandUtil::exec( "pkexec", args, data );
    } catch ( QString &ex ) {
        qCritical() << ex;
    }

    return result;
}

QString CommandUtil::exec( const QString &cmd, QStringList args, QByteArray data )
{
    QProcess *process = new QProcess;

    process->start( cmd, args );

    if ( ! data.isEmpty() ) {
        process->write( data );
        process->waitForBytesWritten();
        process->closeWriteChannel();
    }

    process->waitForFinished();

    QTextStream stdOut( process->readAllStandardOutput() );

    QString err = process->errorString();

    process->kill();
    process->close();

    if ( process->error() != QProcess::UnknownError ) {
        throw err;
    }

    return stdOut.readAll().trimmed();
}

bool CommandUtil::isExecutable( const QString &cmd )
{
    return !QStandardPaths::findExecutable( cmd ).isEmpty();
}
