/*
    
    * This file is a part of Libcsys.
    * Library for managing drive and getting system resource information in real time for CuboCore Application Suite
	* Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/


#include <libgen.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/statvfs.h>
#include <sys/statfs.h>
#include <unistd.h>
#include "file_util.h"

#include <QFile>
#include <QDir>
#include <QTextStream>
#include <QDirIterator>
#include <QStandardPaths>
#include <QSharedPointer>


QString FileUtil::readStringFromFile( const QString &path, const QIODevice::OpenMode &mode )
{
    QSharedPointer<QFile> file( new QFile( path ) );
    QString data;

    if ( file->open( mode ) ) {
        data = file->readAll();
        file->close();
    }

    return data;
}

QStringList FileUtil::readListFromFile( const QString &path, const QIODevice::OpenMode &mode )
{
    QStringList list = FileUtil::readStringFromFile( path, mode ).trimmed().split( "\n" );

    return list;
}

bool FileUtil::writeFile( const QString &path, const QString &content, const QIODevice::OpenMode &mode )
{
    QFile file( path );

    if ( file.open( mode ) ) {
        QTextStream stream( &file );
        stream << content.toUtf8() << endl;
        file.close();
        return true;
    }

    return false;
}
