/*
    
    * This file is a part of Libcsys.
    * Library for managing drive and getting system resource information in real time for CuboCore Application Suite
	* Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/


#include "network_info.h"

#include "file_util.h"
#include "command_util.h"

#include <QtNetwork/QNetworkInterface>


NetworkInfo::NetworkInfo()
{
    for ( const QNetworkInterface &net : QNetworkInterface::allInterfaces() ) {
        if ( ( net.flags()  & QNetworkInterface::IsUp ) &&
                ( net.flags()  & QNetworkInterface::IsRunning ) &&
                !( net.flags() & QNetworkInterface::IsLoopBack ) ) {
            defaultNetworkInterface = net.name();
            break;
        }
    }

    rxPath = QString( "/sys/class/net/%1/statistics/rx_bytes" ).arg( defaultNetworkInterface );
    txPath = QString( "/sys/class/net/%1/statistics/tx_bytes" ).arg( defaultNetworkInterface );
}

QList<QNetworkInterface> NetworkInfo::getAllInterfaces()
{
    return QNetworkInterface::allInterfaces();
}

QString NetworkInfo::getDefaultNetworkInterface() const
{
    return defaultNetworkInterface;
}

quint64 NetworkInfo::getRXbytes() const
{
    quint64 rx = static_cast<quint64>( FileUtil::readStringFromFile( rxPath ).trimmed().toLong() );

    return rx;
}

quint64 NetworkInfo::getTXbytes() const
{
    quint64 tx = static_cast<quint64>( FileUtil::readStringFromFile( txPath ).trimmed().toLong() );

    return tx;
}
